files = ...
    { % filename, start record no., end record no. (to select) or 1 and inf.
         '016_20240702UTC144244.log', 1, inf;
         '013_20240702UTC142404.log', 1, inf;
         '010_20240702UTC140636.log', 12, inf;
         '011_20240702UTC141335.log', 18, inf;
         '012_20240702UTC141953.log', 8, inf;
         '014_20240702UTC143006.log', 18, inf;
         '015_20240702UTC143534.log', 1, inf;
         % '', nan, nan;
         %'017_20240702UTC190314 test.log', 1, inf; % test log
    };


data = cell(size(files,1),8);
% data columns
% 1 exp number
% 2 exp name
% 3 start record number to use (1 or larger)
% 4 end record number to use (inf or smaller)
% 5 target accumulation
% 6 initial accumulation

MFD = [];
MFD_title = 'MFD of exp. '; % for figure

for i = 1:size(files,1)
    fileID = fopen(files{i,1}, 'r');
    
    if fileID == -1
        error('File could not be opened.');
    end
    
    line = fgetl(fileID);
    ExpNo = str2double(line(9:end));
    
    line = fgetl(fileID);
    ExpName = line(7:end);
    
    line = fgetl(fileID);
    Ta = str2double(line(21:end));
    
    line =fgetl(fileID);
    InitAcc =  str2double(line(22:end));
    
    data(i,1:6) = {ExpNo, ExpName, files{i,2}, files{i,3}, Ta, InitAcc};
    % disp(['Exp no.:' num2str(ExpNo)]);
    
    % Measurements columns:
    % 1 dateTime string
    % 2 posix time (number of seconds)
    % 3 event type string (entry, entry_correction, exit, exit_correction)
    % 4 recorded change of N (1 or -1, inflow or outflow)
    % 5 recorded accumulation (ped)
    % 6 after processing: inflow (0, 1, or -1)
    % 7 after processing: outflow (0, 1, or -1)
    
    measurements = {};
    
    % Read file line-by-line
    while ~feof(fileID)
        line = fgetl(fileID);  % Read the current line
        parsedValues = strsplit(line, ',');
        
        if strcmp(parsedValues{1},'stop')
            break;
        end
        
        % Convert date and time strings to datetime object
        dateTime = datetime(parsedValues{1}, 'InputFormat', 'yyyyMMdd''T''HHmmss.SSSSSS');
        %disp(['Date-Time: ' datestr(dateTime,'yyyy-mm-dd HH:MM:SS.FFF')]);
        %jparsedValues{1,2:end}
        
        measurements(end+1,:) = {dateTime, posixtime(dateTime), ...
            parsedValues{1,2}, str2double(parsedValues{1,3}), ...
            str2double(parsedValues{1,4})};
    end
    
    % Close the file
    fclose(fileID);
    
    % data{i,6} % initial accumulation
    for j = 1:size(measurements,1)
        % generate inflow
        if strcmp(measurements{j,3},'entry') || strcmp(measurements{j,3}, 'entry_correction')
            measurements{j,6} = measurements{j,4};
        else
            measurements{j,6} = 0;
        end
        
        % generate outflow
        if strcmp(measurements{j,3},'exit') || strcmp(measurements{j,3}, 'exit_correction')
            measurements{j,7} = - measurements{j,4};
        else
            measurements{j,7} = 0;
        end
        
%         % generate calculated accumulation (for check)
%         if j == 1
%             N(1) = data{i,6} + measurements{j,6} - measurements{j,7}; % initial accumulation
%         else
%             N(j) = N(j-1) + measurements{j,6} - measurements{j,7};
%         end
          % N == [measurements{:,5}]
    end
    
    data{i,7} = measurements;
    
    % data{i,3} and data{i,4} is the range of wanted data if not nan
    % the rest is left out (warm up, etc.)  
    % restrict beginning
    
    % ... to the first moment that the target accumulation is reached
    % data{i,3} = max(data{i,3},find([measurements{:,5}]==data{i,5},1));
    % ... to the first moment that outflow is generated
    % data{i,3} = max(data{i,3},find([measurements{:,7}],1));
    % no start cut
    % data{i,3} = 1
    
    % restrict end
    data{i,4} = min(data{i,4},size(measurements,1));
    dstart = data{i,3};
    dend = data{i,4};
    
    figure()
    subplot(2,1,1)
    t = [measurements{dstart:dend,2}]-measurements{1,2};
    N_in = cumsum([measurements{dstart:dend,6}])+measurements{dstart,5};
    N_out = cumsum([measurements{dstart:dend,7}]);
    Acc = [measurements{dstart:dend,5}];
    
    
    s_in = stairs(t,N_in);
    hold on
    s_out = stairs(t,N_out);
    title(['Exp. No. ', num2str(ExpNo), ', Target Acc.', num2str(Ta)]);
    xlabel('time (s)')
    ylabel('cumulative ped')
    legend([s_in,s_out],{'in','out'})
    xl = [-1, t(end)+1];
    yl = [min(N_in(1),N_out(1))-1, max(N_in(end),N_out(end)+1)];
    xlim(xl)
    ylim(yl)
    
    subplot(2,1,2)
    stairs(t,Acc)
    xlabel('time (s)')
    ylabel('accumulation (ped)')
    xlim(xl)
    ylim([-1,max(Acc)+1]);

    print([num2str(ExpNo),'_',ExpName,'.jpg'],'-djpeg','-r300');

    % for MFD
    mean_outflow(i) = (N_out(end)-N_out(1))/(t(end)-t(1));
    mean_acc(i) = (Acc(1:end-1)*diff(t)')/(t(end)-t(1));
    MFD_title = [MFD_title,num2str(data{i,1}),', '];
   
end
    
    % MFD
    figure()
    subplot(2,1,1)
    plot(mean_acc,mean_outflow,'.-')
    title(MFD_title)
    xlabel('mean accumulation (ped)')
    ylabel('outflow (ped/s)')
    
    subplot(2,1,2)
    plot([data{:,5}],mean_outflow,'.-')
    xlabel('target accumulation (ped)')
    ylabel('outflow (ped/s)')

    print(['MFD.jpg'],'-djpeg','-r300');
    
